/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.geronimo.openejb;

import java.util.Properties;
import javax.naming.InitialContext;
import javax.naming.NameNotFoundException;
import javax.naming.NamingException;

import org.apache.geronimo.naming.reference.SimpleReference;

public class ClientEjbReference extends SimpleReference {
    private final String url;
    private final String deploymentId;

    public ClientEjbReference(String url, String deploymentId) {
        this.url = url;
        this.deploymentId = deploymentId;
    }

    public Object getContent() throws NameNotFoundException {
        Properties p = new Properties();
        p.put("java.naming.factory.initial", "org.apache.openejb.client.RemoteInitialContextFactory");
        p.put("java.naming.provider.url", url);
        p.put("openejb.client.moduleId", "openejb/Deployment");

        try {
            InitialContext ctx = new InitialContext(p);
            Object value = ctx.lookup(deploymentId);
            return value;
        } catch (NamingException e) {
            throw (NameNotFoundException) new NameNotFoundException().initCause(e);
        }
    }
}
